_`umbra.ui.widgets.delayed_QSplashScreen`
=========================================

.. automodule:: umbra.ui.widgets.delayed_QSplashScreen

Module Attributes
-----------------

.. attribute:: umbra.ui.widgets.delayed_QSplashScreen.LOGGER

Classes
-------

.. autoclass:: Delayed_QSplashScreen
	:show-inheritance:
	:members:

